diff --git a/.github/.release-please-manifest.json b/.github/.release-please-manifest.json
index cbea53b1..d40f464a 100644
--- a/.github/.release-please-manifest.json
+++ b/.github/.release-please-manifest.json
@@ -1,3 +1,3 @@
{
- ".": "15.8.1"
+ ".": "15.10.1"
}
diff --git a/CHANGELOG.md b/CHANGELOG.md
index 033109a4..cb35b779 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,5 +1,88 @@
# Changelog
+## [15.10.1](https://github.com/LazyVim/LazyVim/compare/v15.10.0...v15.10.1) (2025-10-20)
+
+
+### Bug Fixes
+
+* **avante:** correct key mapping declarations ([#6656](https://github.com/LazyVim/LazyVim/issues/6656)) ([41d1b8d](https://github.com/LazyVim/LazyVim/commit/41d1b8dc72d4270c49db3365edba670d9fa01fbd))
+* **blink:** added work-around back for unsupported native snippets ([899533a](https://github.com/LazyVim/LazyVim/commit/899533a101e4bacf35dadf091977b4d12875dbf6))
+* **treesitter:** added buf to treesitter start just to be sure ([3ffb471](https://github.com/LazyVim/LazyVim/commit/3ffb471c187a66562b19bdf68382be9f82ac670d))
+
+## [15.10.0](https://github.com/LazyVim/LazyVim/compare/v15.9.0...v15.10.0) (2025-10-20)
+
+
+### Features
+
+* **ai:** add avante.nvim for a better AI experience ([#4440](https://github.com/LazyVim/LazyVim/issues/4440)) ([2682ce0](https://github.com/LazyVim/LazyVim/commit/2682ce0ab95c0a88867855ada41948107db8232e))
+* **extra:** allow users to add custom bundles through opts.init_options.bundles to jdtls ([#6265](https://github.com/LazyVim/LazyVim/issues/6265)) ([faeb24b](https://github.com/LazyVim/LazyVim/commit/faeb24ba956f103c5551bde11506991d8b594bc5))
+* **extras:** add Dart language ([#4749](https://github.com/LazyVim/LazyVim/issues/4749)) ([90f84e7](https://github.com/LazyVim/LazyVim/commit/90f84e7e755f72bb99dc8a9dedbfef05e58eb09d))
+* **extras:** added ember lang support ([#6203](https://github.com/LazyVim/LazyVim/issues/6203)) ([ac4cce0](https://github.com/LazyVim/LazyVim/commit/ac4cce0f2f436b3e2dd93ad9179178436ab8c600))
+* **extras:** added twig language ([#5464](https://github.com/LazyVim/LazyVim/issues/5464)) ([a6eb51e](https://github.com/LazyVim/LazyVim/commit/a6eb51e5b5897749bed8721ce98cd2491b2ea8e2))
+* **extras:** ai: add `claudecode.nvim` ([#6229](https://github.com/LazyVim/LazyVim/issues/6229)) ([e7a3e80](https://github.com/LazyVim/LazyVim/commit/e7a3e80ee1327ac012c7bb7257bb2d49f9f2fd89))
+* **extras:** automatically update lazyvim.json for renamed or deprecated extras ([37ecd06](https://github.com/LazyVim/LazyVim/commit/37ecd06fad65d5c188ad2d2e55d47a8fd1594d16))
+* **extras:** renamed extra omnisharp -> dotnet + added fautocomplete to lspconfig ([1b2e6e8](https://github.com/LazyVim/LazyVim/commit/1b2e6e8986b3cfee19635920129fc08df4f32b38))
+* **extras:** utils: add `gh.nvim` ([#6250](https://github.com/LazyVim/LazyVim/issues/6250)) ([8db9c75](https://github.com/LazyVim/LazyVim/commit/8db9c75e8d3a8609926dcb868d2e462e0f0b1d3d))
+* **go:** add linting with golangci-lint ([#6311](https://github.com/LazyVim/LazyVim/issues/6311)) ([248876a](https://github.com/LazyVim/LazyVim/commit/248876adb6b1f54031be350e45bbf0c7835d486f))
+* **haskell:** update `haskell-tools` version and add formatters + linters ([#6230](https://github.com/LazyVim/LazyVim/issues/6230)) ([82382f4](https://github.com/LazyVim/LazyVim/commit/82382f455ad37bc4fa928fe4a6fb9379a924fa3a))
+* **lang/fsharp:** add F# support to omnisharp extra ([#6538](https://github.com/LazyVim/LazyVim/issues/6538)) ([80a980a](https://github.com/LazyVim/LazyVim/commit/80a980ab00a871777c37ec3f0db9c394509b2465))
+* **lang:** add neotest config for PHP tests ([#5958](https://github.com/LazyVim/LazyVim/issues/5958)) ([9b077c7](https://github.com/LazyVim/LazyVim/commit/9b077c7a8ec96050f3a3b73219c8b904d3d83ab0))
+* **lang:** add solidity language support ([#4742](https://github.com/LazyVim/LazyVim/issues/4742)) ([2cd46d4](https://github.com/LazyVim/LazyVim/commit/2cd46d42ba357a42b11c5e4f5e16641bde0516d6))
+* **lang:** add Typst language support ([#4042](https://github.com/LazyVim/LazyVim/issues/4042)) ([645846b](https://github.com/LazyVim/LazyVim/commit/645846be5c7d798c7e87e61d00e8cae4fd3741c7))
+* **lang:** julia support ([#6231](https://github.com/LazyVim/LazyVim/issues/6231)) ([5d186c0](https://github.com/LazyVim/LazyVim/commit/5d186c009a85efbdad2b92115d4268c7c4a7aa18))
+* **lang:** nix add `statix` linter ([#6244](https://github.com/LazyVim/LazyVim/issues/6244)) ([2a866f6](https://github.com/LazyVim/LazyVim/commit/2a866f6c8c974c88cb9c723560cbec4308d304a2))
+* **sidekick:** added sidekick cli status to lualine ([16917db](https://github.com/LazyVim/LazyVim/commit/16917db94a056fe01b3bac604bc89da4077bd9cd))
+
+
+### Bug Fixes
+
+* **extras.lang:** fix Scala extra by using nvimMetals only ([#5726](https://github.com/LazyVim/LazyVim/issues/5726)) ([f118dca](https://github.com/LazyVim/LazyVim/commit/f118dca334d40cf8e78e0f0d5aa3108b972e8d84))
+* **fzf-lua:** added some missing keymaps similar to snacks picker. Closes [#6036](https://github.com/LazyVim/LazyVim/issues/6036). Closes [#5830](https://github.com/LazyVim/LazyVim/issues/5830) ([69a5744](https://github.com/LazyVim/LazyVim/commit/69a57448032253ca086d999c0d53d6e33ad4e505))
+* **helm:** broken helm highlighting ([#5335](https://github.com/LazyVim/LazyVim/issues/5335)) ([4d0d87f](https://github.com/LazyVim/LazyVim/commit/4d0d87f6268969987e5c58f59e086c886e77e1ae))
+* **keymap:** remove select mode remaps of printable characters ([#6296](https://github.com/LazyVim/LazyVim/issues/6296)) ([83468be](https://github.com/LazyVim/LazyVim/commit/83468be35062d06896c233d90d2f1c1cd24d84f3))
+* **tailwind:** additional settings ([#5266](https://github.com/LazyVim/LazyVim/issues/5266)) ([d2f9885](https://github.com/LazyVim/LazyVim/commit/d2f9885d6b8244818066cc16a5c72cb656748f6c))
+* **telescope:** sync keymaps with snacks picker + added some that were missing ([1a08e9f](https://github.com/LazyVim/LazyVim/commit/1a08e9f50f8c11a329c3017c4bfdd4b96b7ec541))
+* **twig:** correct mason url ([9d345de](https://github.com/LazyVim/LazyVim/commit/9d345dec446f577f75d36a147164ae258ffc2d8c))
+* **typescript:** better default pwa-node DAP config. Closes [#6386](https://github.com/LazyVim/LazyVim/issues/6386) ([e4d3432](https://github.com/LazyVim/LazyVim/commit/e4d34328f244fc0c7f91587258e767bfb55d0648))
+* **typescript:** support chrome, node and msedge dap adapters ([#6649](https://github.com/LazyVim/LazyVim/issues/6649)) ([0b65d33](https://github.com/LazyVim/LazyVim/commit/0b65d33d8545d179207c8827025f40764de61d06))
+* **util.project:** different mapping on dashboard than `snacks.projects` ([#5737](https://github.com/LazyVim/LazyVim/issues/5737)) ([e389447](https://github.com/LazyVim/LazyVim/commit/e38944799e7fc45baea0483f5c955472f3ffde27))
+
+
+### Reverts
+
+* "feat(extra): allow users to add custom bundles through opts.init_options.bundles to jdtls ([#6265](https://github.com/LazyVim/LazyVim/issues/6265))" ([#6650](https://github.com/LazyVim/LazyVim/issues/6650)) ([a582f00](https://github.com/LazyVim/LazyVim/commit/a582f004473a3bade99c19c62fea649fb0b1c20f))
+
+## [15.9.0](https://github.com/LazyVim/LazyVim/compare/v15.8.1...v15.9.0) (2025-10-19)
+
+
+### Features
+
+* **docker:** associate 'Containerfile' with 'dockerfile' filetype ([#5974](https://github.com/LazyVim/LazyVim/issues/5974)) ([97af4a2](https://github.com/LazyVim/LazyVim/commit/97af4a23bccac85eb02e489f573db68863d6ed33))
+* **extras.rest:** add keymap for changing environment ([#5678](https://github.com/LazyVim/LazyVim/issues/5678)) ([1da659d](https://github.com/LazyVim/LazyVim/commit/1da659db4a3fbcd6d171f3b38d0092ced0887e61))
+* **java:** enable `blink.cmp` capabilities to show signature documentation ([#5218](https://github.com/LazyVim/LazyVim/issues/5218)) ([9618e32](https://github.com/LazyVim/LazyVim/commit/9618e327edfb79d9cbb037a2039c4315a95df63f))
+* **lang/omnisharp:** switch neotest adapter to vstest ([#6540](https://github.com/LazyVim/LazyVim/issues/6540)) ([4086d44](https://github.com/LazyVim/LazyVim/commit/4086d44a0b5c576630c603c7b71c6be5198d9eaf))
+* **neotest:** extra keymap to attach to a test ([#6198](https://github.com/LazyVim/LazyVim/issues/6198)) ([66e927f](https://github.com/LazyVim/LazyVim/commit/66e927fd9d0b0ff2886b9fe1465d9396461a2665))
+
+
+### Bug Fixes
+
+* **blink:** remove snippet expand override (no longer needed). Closes [#6044](https://github.com/LazyVim/LazyVim/issues/6044) ([336e2c3](https://github.com/LazyVim/LazyVim/commit/336e2c3ea67636c4eea3cf8f7538feb86b5a0610))
+* **chezmoi:** add `hidden=false` to fzf picker ([#6095](https://github.com/LazyVim/LazyVim/issues/6095)) ([1aa1b59](https://github.com/LazyVim/LazyVim/commit/1aa1b59a7ec7cab61fa7b096db53df15ec5008e7))
+* **copilot-chat:** use up to date config for chat headers ([#6543](https://github.com/LazyVim/LazyVim/issues/6543)) ([2c5eef7](https://github.com/LazyVim/LazyVim/commit/2c5eef7df7520fbc6fe0d90150cd26ac9e4f325b))
+* **extras/rust:** fix config key for files.exclude ([#5664](https://github.com/LazyVim/LazyVim/issues/5664)) ([762a34d](https://github.com/LazyVim/LazyVim/commit/762a34d5ad95447b241287e8d540b657a699d141))
+* **extras:** adjust switch source/header shortcut ([#6567](https://github.com/LazyVim/LazyVim/issues/6567)) ([b36b858](https://github.com/LazyVim/LazyVim/commit/b36b8589b62f55b181367afe954606c73233c0a1))
+* **extras:** remove procMacro ignored ([#6117](https://github.com/LazyVim/LazyVim/issues/6117)) ([4a3702e](https://github.com/LazyVim/LazyVim/commit/4a3702e050881fea262ccae980ae1ff9e849d275))
+* **lang.omnisharp:** update CSharpier command and arguments for Mason compatibility ([#6156](https://github.com/LazyVim/LazyVim/issues/6156)) ([dfebe70](https://github.com/LazyVim/LazyVim/commit/dfebe70b8d09514dd3ee85e12463f266f93c5dd7))
+* **lang.rust:** rust-analyzer hanging on root scanned ([#6178](https://github.com/LazyVim/LazyVim/issues/6178)) ([7bf8c22](https://github.com/LazyVim/LazyVim/commit/7bf8c22c56283fa6d5d35246dcd0f49d37a5c709))
+* **latex:** ensure tex extra installs latex tree-sitter parser ([#6357](https://github.com/LazyVim/LazyVim/issues/6357)) ([ae74622](https://github.com/LazyVim/LazyVim/commit/ae74622e6666ea4c3e6c58c4ef2d3f313d8e8f20))
+* **mini.animate:** schedule the toggle mapping to correctly take effect ([#6483](https://github.com/LazyVim/LazyVim/issues/6483)) ([bd23357](https://github.com/LazyVim/LazyVim/commit/bd233579a66018f526b6b0970e33afde4cde399e))
+* **sql:** fix autocomplete when `omni` is used as a `blink.cmp` source ([#5652](https://github.com/LazyVim/LazyVim/issues/5652)) ([f6f72b9](https://github.com/LazyVim/LazyVim/commit/f6f72b90d41d9347b93a07d0b680195541f64c55))
+* **treesitter:** attach textobject keymaps to existing buffers on load. Closes [#6642](https://github.com/LazyVim/LazyVim/issues/6642). Closes [#6639](https://github.com/LazyVim/LazyVim/issues/6639) ([92a7728](https://github.com/LazyVim/LazyVim/commit/92a77287321236f52ff38648a38cf314ab223137))
+* **typescript:** make_position_params with offset encoding. ([#6277](https://github.com/LazyVim/LazyVim/issues/6277)) ([22152e9](https://github.com/LazyVim/LazyVim/commit/22152e958f3f7c2b732cb6429ccc90541e0ad17f))
+* **ui:** ignore sidekick_terminal in mini-indentscope ([#6619](https://github.com/LazyVim/LazyVim/issues/6619)) ([f0b32b5](https://github.com/LazyVim/LazyVim/commit/f0b32b5955889d4d2d3636a52d2ddf5d113646df))
+* **util:** add some kulala keymaps back to global ([#5960](https://github.com/LazyVim/LazyVim/issues/5960)) ([a16739e](https://github.com/LazyVim/LazyVim/commit/a16739e3328c2687d96f868839c575765c49baad))
+* **vscode:** don't sync undo/redo with vscode ([#5957](https://github.com/LazyVim/LazyVim/issues/5957)) ([706ec44](https://github.com/LazyVim/LazyVim/commit/706ec4443a33ec474f2329b5b806e9cdb85cce43))
+
## [15.8.1](https://github.com/LazyVim/LazyVim/compare/v15.8.0...v15.8.1) (2025-10-18)
diff --git a/README-FR.md b/README-FR.md
new file mode 100644
index 00000000..db06a251
--- /dev/null
+++ b/README-FR.md
@@ -0,0 +1,151 @@
+
+

+
+
+
+
+
+
+
+
+LazyVim est une configuration Neovim basée sur [💤 lazy.nvim](https://github.com/folke/lazy.nvim)
+facilitant la personnalisation et l'ajout d'extensions.
+Plutôt que d'imposer le choix entre partir de rien et utiliser
+une distribution toute faite, LazyVim offre le meilleur des deux mondes
+: la flexibilité d'une config ajustable selon vos besoins, et le confort
+d'une configuration pensée et peaufinée à l'avance.
+
+
+
+
+
+## ✨ Fonctionnalités
+
+- 🔥 Transforme Neovim en un environnement de développement complet
+- 💤 Customise et étends ta config sans effort grâce à [lazy.nvim](https://github.com/folke/lazy.nvim)
+- 🚀 Rapide comme l'éclair !
+- 🧹 Configuration par défaut propre et intuitive pour les options, les autocmds, et les keymaps
+- 📦 Livré avec une variété de plugins pre-configurés et prêts à être utilisés
+
+## ⚡️ Pré-requis
+
+- Neovim >= **0.9.0** (doit être compilé avec **LuaJIT**)
+- Git >= **2.19.0** (pour supporter le clonage partiel)
+- Un [Nerd Font](https://www.nerdfonts.com/) **_(optionel)_**
+- Un compileur **C** pour `nvim-treesitter`. Voir [ici](https://github.com/nvim-treesitter/nvim-treesitter#requirements)
+
+## 🚀 Comment commencer
+
+Un template pour **LazyVim** peut être trouvé [ici](https://github.com/LazyVim/starter)
+
+Essayer avec Docker
+
+```sh
+docker run -w /root -it --rm alpine:edge sh -uelic '
+ apk add git lazygit fzf curl neovim ripgrep alpine-sdk --update
+ git clone https://github.com/LazyVim/starter ~/.config/nvim
+ cd ~/.config/nvim
+ nvim
+'
+```
+
+
+
+Installer le LazyVim Starter
+
+- Sauvegardez votre configuration Neovim :
+
+ ```sh
+ mv ~/.config/nvim ~/.config/nvim.bak
+ mv ~/.local/share/nvim ~/.local/share/nvim.bak
+ ```
+
+- Clonez le starter
+
+ ```sh
+ git clone https://github.com/LazyVim/starter ~/.config/nvim
+ ```
+
+- Supprimez le dossier `.git`, afin que vous puissiez l'ajouter à votre repo plus tard
+
+ ```sh
+ rm -rf ~/.config/nvim/.git
+ ```
+
+- Lancez Neovim !
+
+ ```sh
+ nvim
+ ```
+
+ Consultez les commentaires dans les fichiers pour savoir comment personnaliser **LazyVim**.
+
+
+
+---
+
+Il y a une superbe vidéo (en anglais) de [@elijahmanor](https://github.com/elijahmanor)
+qui vous guide pas-à-pas pour commencer.
+
+[](https://www.youtube.com/watch?v=N93cTbtLCIM)
+
+[@dusty-phillips](https://github.com/dusty-phillips) a écrit un livre exhaustif
+sur LazyVim, nommé [LazyVim for Ambitious Developers](https://lazyvim-ambitious-devs.phillips.codes)
+disponible gratuitement en ligne.
+
+## 📂 Structure de fichier
+
+Les fichiers dans le dossier config vont être chargés automatiquement en temps voulu,
+donc pas besoin de `require` ces fichiers manuellement.
+**LazyVim** vient avec un ensemble de fichiers de configuration par défaut qui seront chargés
+**_avant_** les vôtres. Voir [ici](https://github.com/LazyVim/LazyVim/tree/main/lua/lazyvim/config)
+
+Vous pouvez ajouter vos configurations de plugins sous `lua/plugins/`.
+Ici, tous les fichiers seront automatiquement chargés par [lazy.nvim](https://github.com/folke/lazy.nvim)
+
+
+~/.config/nvim
+├── lua
+│ ├── config
+│ │ ├── autocmds.lua
+│ │ ├── keymaps.lua
+│ │ ├── lazy.lua
+│ │ └── options.lua
+│ └── plugins
+│ ├── spec1.lua
+│ ├── **
+│ └── spec2.lua
+└── init.lua
+
+
+## ⚙️ Configuration
+
+Veuillez vous référer à la [documentation](https://lazyvim.github.io)
diff --git a/README-PL.md b/README-PL.md
new file mode 100644
index 00000000..912e971e
--- /dev/null
+++ b/README-PL.md
@@ -0,0 +1,147 @@
+
+

+
+
+
+
+
+
+
+
+LazyVim to konfiguracja Neovim oparta na [💤 lazy.nvim](https://github.com/folke/lazy.nvim)
+która ułatwia dostosowywanie i rozszerzanie konfiguracji.
+Zamiast wybierać między rozpoczynaniem od zera a używaniem gotowej dystrybucji, LazyVim oferuje najlepsze z obu światów – elastyczność pozwalającą na dostosowanie konfiguracji do własnych potrzeb oraz wygodę wstępnie skonfigurowanego środowiska.
+
+
+
+
+
+## ✨ Funkcje
+
+- 🔥 Przekształć Neovim w pełnoprawne IDE
+- 💤 Łatwo dostosowuj i rozszerzaj swoją konfigurację dzięki [lazy.nvim](https://github.com/folke/lazy.nvim)
+- 🚀 Niezwykle szybkie działanie
+- 🧹 Przemyślane domyślne ustawienia opcji, autocmd i skrótów klawiszowych
+- 📦 Zawiera bogaty zestaw wstępnie skonfigurowanych wtyczek gotowych do użycia
+
+## ⚡️ Wymagania
+
+- Neovim >= **0.9.0** (musi być skompilowany z **LuaJIT**)
+- Git >= **2.19.0** (dla obsługi częściowego klonowania repozytoriów)
+- [Nerd Font](https://www.nerdfonts.com/) **_(opcjonalnie)_**
+- Kompilator **C** wymagany dla `nvim-treesitter`. Szczegóły [tutaj](https://github.com/nvim-treesitter/nvim-treesitter#requirements)
+
+## 🚀 Pierwsze kroki
+
+Szablon startowy dla **LazyVim** znajdziesz [tutaj](https://github.com/LazyVim/starter)
+
+Wypróbuj z Dockerem
+
+```sh
+docker run -w /root -it --rm alpine:edge sh -uelic '
+ apk add git lazygit fzf curl neovim ripgrep alpine-sdk --update
+ git clone https://github.com/LazyVim/starter ~/.config/nvim
+ cd ~/.config/nvim
+ nvim
+'
+```
+
+
+
+Zainstaluj Starter LazyVim
+
+- Wykonaj kopię zapasową swoich obecnych plików Neovim:
+
+ ```sh
+ mv ~/.config/nvim ~/.config/nvim.bak
+ mv ~/.local/share/nvim ~/.local/share/nvim.bak
+ ```
+
+- Sklonuj repozytorium startowe:
+
+ ```sh
+ git clone https://github.com/LazyVim/starter ~/.config/nvim
+ ```
+
+- Usuń folder `.git`, aby później móc dodać własne repozytorium:
+
+ ```sh
+ rm -rf ~/.config/nvim/.git
+ ```
+
+- Uruchom Neovim!
+
+ ```sh
+ nvim
+ ```
+
+ W plikach znajdziesz komentarze, które pomogą Ci dostosować **LazyVim**.
+
+
+
+---
+
+[@elijahmanor](https://github.com/elijahmanor) stworzył świetne wideo z przewodnikiem, jak zacząć.
+
+[](https://www.youtube.com/watch?v=N93cTbtLCIM)
+
+[@dusty-phillips](https://github.com/dusty-phillips) napisał obszerną książkę
+[LazyVim for Ambitious Developers](https://lazyvim-ambitious-devs.phillips.codes),
+która jest dostępna za darmo online.
+
+## 📂 Struktura plików
+
+Pliki w katalogu `config` są automatycznie ładowane w odpowiednim momencie,
+więc nie musisz ich ręcznie dołączać.
+**LazyVim** zawiera zestaw domyślnych plików konfiguracyjnych,
+które zostaną załadowane **_przed_** Twoimi własnymi. Szczegóły znajdziesz [tutaj](https://github.com/LazyVim/LazyVim/tree/main/lua/lazyvim/config).
+
+Możesz dodać własne specyfikacje wtyczek w katalogu `lua/plugins/`.
+Wszystkie pliki w tym folderze zostaną automatycznie załadowane przez [lazy.nvim](https://github.com/folke/lazy.nvim).
+
+
+~/.config/nvim
+├── lua
+│ ├── config
+│ │ ├── autocmds.lua
+│ │ ├── keymaps.lua
+│ │ ├── lazy.lua
+│ │ └── options.lua
+│ └── plugins
+│ ├── spec1.lua
+│ ├── **
+│ └── spec2.lua
+└── init.lua
+
+
+## ⚙️ Konfiguracja
+
+Zapoznaj się z [dokumentacją](https://lazyvim.github.io).
diff --git a/README.md b/README.md
index 1e7bb70d..b8357744 100644
--- a/README.md
+++ b/README.md
@@ -111,10 +111,6 @@ docker run -w /root -it --rm alpine:edge sh -uelic '
---
-There's a great video created by [@elijahmanor](https://github.com/elijahmanor) with a walkthrough to get started.
-
-[](https://www.youtube.com/watch?v=N93cTbtLCIM)
-
[@dusty-phillips](https://github.com/dusty-phillips) wrote a comprehensive book called
[LazyVim for Ambitious Developers](https://lazyvim-ambitious-devs.phillips.codes)
available for free online.
diff --git a/doc/LazyVim.txt b/doc/LazyVim.txt
index dd6610d3..3064b624 100644
--- a/doc/LazyVim.txt
+++ b/doc/LazyVim.txt
@@ -1,4 +1,4 @@
-*LazyVim.txt* For Neovim Last change: 2025 October 18
+*LazyVim.txt* For Neovim Last change: 2025 October 22
==============================================================================
Table of Contents *LazyVim-table-of-contents*
@@ -97,11 +97,6 @@ Install the LazyVim Starter ~
Refer to the comments in the files on how to customize **LazyVim**.
------------------------------------------------------------------------------
-There’s a great video created by @elijahmanor
- with a walkthrough to get started.
-
-
-
@dusty-phillips wrote a comprehensive book
called LazyVim for Ambitious Developers
available for free online.
@@ -127,9 +122,7 @@ Refer to the docs
1. *image*: https://user-images.githubusercontent.com/292349/211285846-0b7bb3bf-0462-4029-b64c-4ee1d037fc1c.png
2. *image*: https://user-images.githubusercontent.com/292349/213447056-92290767-ea16-430c-8727-ce994c93e9cc.png
-3. *@elijahmanor*:
-4. *Watch the video*: https://img.youtube.com/vi/N93cTbtLCIM/hqdefault.jpg
-5. *@dusty-phillips*:
+3. *@dusty-phillips*:
Generated by panvimdoc
diff --git a/lua/lazyvim/config/init.lua b/lua/lazyvim/config/init.lua
index ab41d775..023bc6ec 100644
--- a/lua/lazyvim/config/init.lua
+++ b/lua/lazyvim/config/init.lua
@@ -3,7 +3,7 @@ _G.LazyVim = require("lazyvim.util")
---@class LazyVimConfig: LazyVimOptions
local M = {}
-M.version = "15.8.1" -- x-release-please-version
+M.version = "15.10.1" -- x-release-please-version
LazyVim.config = M
---@class LazyVimOptions
diff --git a/lua/lazyvim/config/keymaps.lua b/lua/lazyvim/config/keymaps.lua
index e83cf6e6..80a40231 100644
--- a/lua/lazyvim/config/keymaps.lua
+++ b/lua/lazyvim/config/keymaps.lua
@@ -80,8 +80,8 @@ map({ "i", "x", "n", "s" }, "", "w", { desc = "Save File" })
map("n", "K", "norm! K", { desc = "Keywordprg" })
-- better indenting
-map("v", "<", "", ">gv")
+map("x", "<", "", ">gv")
-- commenting
map("n", "gco", "oVcxnormal gccfxa", { desc = "Add Comment Below" })
@@ -107,7 +107,7 @@ map("n", "[q", vim.cmd.cprev, { desc = "Previous Quickfix" })
map("n", "]q", vim.cmd.cnext, { desc = "Next Quickfix" })
-- formatting
-map({ "n", "v" }, "cf", function()
+map({ "n", "x" }, "cf", function()
LazyVim.format({ force = true })
end, { desc = "Format" })
diff --git a/lua/lazyvim/plugins/editor.lua b/lua/lazyvim/plugins/editor.lua
index 5324c3fe..1d5f137a 100644
--- a/lua/lazyvim/plugins/editor.lua
+++ b/lua/lazyvim/plugins/editor.lua
@@ -18,7 +18,7 @@ return {
},
})
end,
- mode = { "n", "v" },
+ mode = { "n", "x" },
desc = "Search and Replace",
},
},
@@ -64,7 +64,7 @@ return {
defaults = {},
spec = {
{
- mode = { "n", "v" },
+ mode = { "n", "x" },
{ "", group = "tabs" },
{ "c", group = "code" },
{ "d", group = "debug" },
@@ -167,8 +167,8 @@ return {
end, "Prev Hunk")
map("n", "]H", function() gs.nav_hunk("last") end, "Last Hunk")
map("n", "[H", function() gs.nav_hunk("first") end, "First Hunk")
- map({ "n", "v" }, "ghs", ":Gitsigns stage_hunk", "Stage Hunk")
- map({ "n", "v" }, "ghr", ":Gitsigns reset_hunk", "Reset Hunk")
+ map({ "n", "x" }, "ghs", ":Gitsigns stage_hunk", "Stage Hunk")
+ map({ "n", "x" }, "ghr", ":Gitsigns reset_hunk", "Reset Hunk")
map("n", "ghS", gs.stage_buffer, "Stage Buffer")
map("n", "ghu", gs.undo_stage_hunk, "Undo Stage Hunk")
map("n", "ghR", gs.reset_buffer, "Reset Buffer")
diff --git a/lua/lazyvim/plugins/extras/ai/avante.lua b/lua/lazyvim/plugins/extras/ai/avante.lua
deleted file mode 100644
index bea59808..00000000
--- a/lua/lazyvim/plugins/extras/ai/avante.lua
+++ /dev/null
@@ -1,338 +0,0 @@
-local M = {}
-local function createPrompt(description, note, prompt)
- return {
- name = description,
- description = description,
- prompt = prompt,
- details = string.format(
- [[
-You are a %s expert. Your task is to %s.
-NOTE:
-%s
-RETURN ONLY THE CODE AND NECESSARY COMMENTS WHEN ASKED.]],
- description,
- prompt,
- note
- ),
- }
-end
-function M.getPrompts()
- return {
- createPrompt(
- "前端工程师",
- [[- Ensure your solutions are responsive and compatible across different devices and browsers.
- - Focus on performance, accessibility, and user experience.]],
- "develop and optimize user interfaces using modern frontend technologies"
- ),
- createPrompt(
- "threejs工程师",
- [[- Ensure your solutions are efficient and render smoothly on different devices.
- - Focus on realistic rendering, lighting, and interactive elements.]],
- "create and optimize 3D graphics using Three.js"
- ),
- createPrompt(
- "Vim/Nvim 高手",
- [[- Provide detailed steps and explanations.
- - Focus on enhancing productivity and customization.]],
- "help users with advanced configurations, optimizations, and troubleshooting for Vim/Neovim"
- ),
- createPrompt(
- "CSS 工程师",
- [[- Ensure your solutions are responsive and compatible across different devices and browsers.
- - Focus on performance, maintainability, and user experience.]],
- "develop and optimize stylesheets for web applications using modern CSS techniques"
- ),
- createPrompt(
- "React 工程师",
- [[- Ensure your solutions are responsive and compatible across different devices and browsers.
- - Focus on performance, accessibility, and user experience.]],
- "develop and optimize user interfaces using React"
- ),
-
- createPrompt(
- "Vue 工程师",
- [[- Ensure your solutions are responsive and compatible across different devices and browsers.
- - Focus on performance, accessibility, and user experience.]],
- "develop and optimize user interfaces using Vue.js"
- ),
-
- createPrompt(
- "Vue3 工程师",
- [[- Ensure your solutions are responsive and compatible across different devices and browsers.
- - Focus on performance, accessibility, and user experience.]],
- "develop and optimize user interfaces using Vue 3"
- ),
-
- createPrompt(
- "Node.js 工程师",
- [[- Ensure your solutions are scalable, efficient, and secure.
- - Focus on performance, maintainability, and best practices.]],
- "develop and optimize server-side applications using Node.js"
- ),
-
- createPrompt(
- "Electron 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, security, and user experience.]],
- "develop and optimize desktop applications using Electron"
- ),
-
- createPrompt(
- "SASS/LESS 工程师",
- [[- Ensure your solutions are responsive, maintainable, and compatible across different devices and browsers.
- - Focus on performance, code reusability, and maintainability.]],
- "develop and optimize stylesheets using SASS and LESS"
- ),
- createPrompt(
- "Uni-app 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, cross-platform compatibility, and user experience.]],
- "develop and optimize applications using Uni-app"
- ),
- createPrompt(
- "Linux 工程师",
- [[- Provide detailed steps and explanations for any configurations or optimizations.
- - Ensure solutions are secure, efficient, and maintainable.
- - Focus on performance, security, and best practices.]],
- "manage, optimize, and troubleshoot Linux systems"
- ),
- createPrompt(
- "TailwindCSS 工程师",
- [[- Ensure your solutions are responsive, maintainable, and compatible across different devices and browsers.
- - Focus on performance, code reusability, and maintainability.]],
- "develop and optimize stylesheets using TailwindCSS"
- ),
- createPrompt(
- "Bootstrap 工程师",
- [[- Ensure your solutions are responsive, maintainable, and compatible across different devices and browsers.
- - Focus on performance, code reusability, and maintainability.]],
- "develop and optimize stylesheets and components using Bootstrap"
- ),
- createPrompt(
- "jQuery 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, code reusability, and maintainability.]],
- "develop and optimize web applications using jQuery"
- ),
- createPrompt(
- "TypeScript 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, type safety, and code readability.]],
- "develop and optimize applications using TypeScript"
- ),
- createPrompt(
- "ECharts 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, interactivity, and visual appeal.]],
- "develop and optimize charts and visualizations using ECharts"
- ),
- createPrompt(
- "Docker 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, scalability, and security.]],
- "develop and optimize containerized applications using Docker"
- ),
- createPrompt(
- "Lua 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, readability, and code reusability.]],
- "develop and optimize applications using Lua"
- ),
- createPrompt(
- "Regexp 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, readability, and code reusability.]],
- "develop and optimize regular expressions"
- ),
- createPrompt(
- "Markdown 专家",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on readability, structure, and formatting.]],
- "create and optimize documents using Markdown"
- ),
- createPrompt(
- "SVG 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, visual appeal, and scalability.]],
- "create and optimize graphics using SVG"
- ),
- createPrompt(
- "Git 专家",
- [[- Provide detailed steps and explanations for any configurations or optimizations.
- - Ensure solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, collaboration, and best practices.]],
- "manage and optimize version control using Git"
- ),
- createPrompt(
- "Shell 脚本专家",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, readability, and code reusability.]],
- "develop and optimize shell scripts"
- ),
- createPrompt(
- "HTML 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, accessibility, and code reusability.]],
- "develop and optimize web pages using HTML"
- ),
- createPrompt(
- "Canvas 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, visual appeal, and interactivity.]],
- "develop and optimize graphics using the HTML5 Canvas API"
- ),
- createPrompt(
- "MySQL 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, query optimization, and data integrity.]],
- "develop and optimize database queries and structures using MySQL"
- ),
- createPrompt(
- "C 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, memory management, and code readability.]],
- "develop and optimize software using C"
- ),
- createPrompt(
- "Windows Batch Script 专家",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, readability, and code reusability.]],
- "develop and optimize batch scripts for Windows"
- ),
- createPrompt(
- "PowerShell 脚本专家",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, readability, and code reusability.]],
- "develop and optimize scripts using PowerShell"
- ),
- createPrompt(
- "CSS3 工程师",
- [[- Ensure your solutions are responsive and compatible across different devices and browsers.
- - Focus on performance, maintainability, and user experience.]],
- "develop and optimize stylesheets for web applications using CSS3"
- ),
- createPrompt(
- "HTML5 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, accessibility, and code reusability.]],
- "develop and optimize web pages using HTML5"
- ),
- createPrompt(
- "EJS 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, readability, and code reusability.]],
- "develop and optimize templates using EJS (Embedded JavaScript)"
- ),
- createPrompt(
- "Prisma 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, scalability, and data integrity.]],
- "develop and optimize database schemas and queries using Prisma"
- ),
- createPrompt(
- "NestJS 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, scalability, and code readability.]],
- "develop and optimize applications using NestJS"
- ),
- createPrompt(
- "Layui 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, user experience, and code readability.]],
- "develop and optimize web applications using Layui"
- ),
- createPrompt(
- "Egg.js 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, scalability, and code readability.]],
- "develop and optimize applications using Egg.js"
- ),
- createPrompt(
- "WebGL 工程师",
- [[- Ensure your solutions are efficient, maintainable, and follow best practices.
- - Focus on performance, rendering quality, and code readability.]],
- "develop and optimize web graphics applications using WebGL"
- ),
- }
-end
-return {
- {
- "yetone/avante.nvim",
- build = vim.fn.has("win32") ~= 0 and "powershell -ExecutionPolicy Bypass -File Build.ps1 -BuildFromSource false"
- or "make",
- event = "VeryLazy",
- version = false, -- Never set this value to "*"! Never!
- ---@module 'avante'
- ---@type avante.Config
- opts = {
- instructions_file = "avante.md",
- provider = "openrouter",
- providers = {
- openrouter = {
- __inherited_from = "openai",
- endpoint = "https://openrouter.ai/api/v1",
- api_key_name = "OPENROUTER_API_KEY",
- model = "alibaba/tongyi-deepresearch-30b-a3b:free",
- },
- },
- shortcuts = M.getPrompts(),
- windows = {
- width = 40,
- sidebar_header = {
- enabled = true, -- true, false to enable/disable the header
- align = "center", -- left, center, right for title
- rounded = true,
- },
- edit = {
- border = "rounded",
- start_insert = false, -- Start insert mode when opening the edit window
- },
- ask = {
- floating = false, -- Open the 'AvanteAsk' prompt in a floating window
- start_insert = false, -- Start insert mode when opening the ask window
- border = "rounded",
- ---@type "ours" | "theirs"
- focus_on_apply = "theirs", -- which diff to focus after applying
- },
- },
- },
- dependencies = {
- "nvim-lua/plenary.nvim",
- "MunifTanjim/nui.nvim",
- --- The below dependencies are optional,
- "nvim-mini/mini.pick", -- for file_selector provider mini.pick
- "nvim-telescope/telescope.nvim", -- for file_selector provider telescope
- "hrsh7th/nvim-cmp", -- autocompletion for avante commands and mentions
- "ibhagwan/fzf-lua", -- for file_selector provider fzf
- "stevearc/dressing.nvim", -- for input provider dressing
- "folke/snacks.nvim", -- for input provider snacks
- "nvim-tree/nvim-web-devicons", -- or echasnovski/mini.icons
- "zbirenbaum/copilot.lua", -- for providers='copilot'
- {
- -- Make sure to set this up properly if you have lazy=true
- "MeanderingProgrammer/render-markdown.nvim",
- opts = {
- file_types = { "markdown", "Avante" },
- },
- ft = { "markdown", "Avante" },
- },
- },
- },
- {
- "saghen/blink.cmp",
- optional = true,
- dependencies = { "Kaiser-Yang/blink-cmp-avante", "saghen/blink.compat" },
- opts = {
- sources = {
- default = { "avante" },
- providers = {
- avante = {
- module = "blink-cmp-avante",
- name = "Avante",
- opts = {},
- },
- },
- },
- },
- },
-}
diff --git a/lua/lazyvim/plugins/extras/ai/claudecode.lua b/lua/lazyvim/plugins/extras/ai/claudecode.lua
new file mode 100644
index 00000000..83776767
--- /dev/null
+++ b/lua/lazyvim/plugins/extras/ai/claudecode.lua
@@ -0,0 +1,22 @@
+return {
+ "coder/claudecode.nvim",
+ opts = {},
+ keys = {
+ { "a", "", desc = "+ai", mode = { "n", "v" } },
+ { "ac", "ClaudeCode", desc = "Toggle Claude" },
+ { "af", "ClaudeCodeFocus", desc = "Focus Claude" },
+ { "ar", "ClaudeCode --resume", desc = "Resume Claude" },
+ { "aC", "ClaudeCode --continue", desc = "Continue Claude" },
+ { "ab", "ClaudeCodeAdd %", desc = "Add current buffer" },
+ { "as", "ClaudeCodeSend", mode = "v", desc = "Send to Claude" },
+ {
+ "as",
+ "ClaudeCodeTreeAdd",
+ desc = "Add file",
+ ft = { "NvimTree", "neo-tree", "oil" },
+ },
+ -- Diff management
+ { "aa", "ClaudeCodeDiffAccept", desc = "Accept diff" },
+ { "ad", "ClaudeCodeDiffDeny", desc = "Deny diff" },
+ },
+}
diff --git a/lua/lazyvim/plugins/extras/ai/copilot-chat.lua b/lua/lazyvim/plugins/extras/ai/copilot-chat.lua
index fbf4ee39..536a4e62 100644
--- a/lua/lazyvim/plugins/extras/ai/copilot-chat.lua
+++ b/lua/lazyvim/plugins/extras/ai/copilot-chat.lua
@@ -8,8 +8,11 @@ return {
user = user:sub(1, 1):upper() .. user:sub(2)
return {
auto_insert_mode = true,
- question_header = " " .. user .. " ",
- answer_header = " Copilot ",
+ headers = {
+ user = " " .. user .. " ",
+ assistant = " Copilot ",
+ tool = " Tool ",
+ },
window = {
width = 0.4,
},
@@ -17,14 +20,14 @@ return {
end,
keys = {
{ "", "", ft = "copilot-chat", desc = "Submit Prompt", remap = true },
- { "a", "", desc = "+ai", mode = { "n", "v" } },
+ { "a", "", desc = "+ai", mode = { "n", "x" } },
{
"aa",
function()
return require("CopilotChat").toggle()
end,
desc = "Toggle (CopilotChat)",
- mode = { "n", "v" },
+ mode = { "n", "x" },
},
{
"ax",
@@ -32,7 +35,7 @@ return {
return require("CopilotChat").reset()
end,
desc = "Clear (CopilotChat)",
- mode = { "n", "v" },
+ mode = { "n", "x" },
},
{
"aq",
@@ -46,7 +49,7 @@ return {
end)
end,
desc = "Quick Chat (CopilotChat)",
- mode = { "n", "v" },
+ mode = { "n", "x" },
},
{
"ap",
@@ -54,7 +57,7 @@ return {
require("CopilotChat").select_prompt()
end,
desc = "Prompt Actions (CopilotChat)",
- mode = { "n", "v" },
+ mode = { "n", "x" },
},
},
config = function(_, opts)
diff --git a/lua/lazyvim/plugins/extras/ai/sidekick.lua b/lua/lazyvim/plugins/extras/ai/sidekick.lua
index d0451fce..c1c38c58 100644
--- a/lua/lazyvim/plugins/extras/ai/sidekick.lua
+++ b/lua/lazyvim/plugins/extras/ai/sidekick.lua
@@ -39,6 +39,19 @@ return {
return { fg = Snacks.util.color(hl) }
end,
})
+
+ table.insert(opts.sections.lualine_x, 2, {
+ function()
+ local status = require("sidekick.status").cli()
+ return " " .. (#status > 1 and #status or "")
+ end,
+ cond = function()
+ return #require("sidekick.status").cli() > 0
+ end,
+ color = function()
+ return { fg = Snacks.util.color("Special") }
+ end,
+ })
end,
},
@@ -114,7 +127,7 @@ return {
picker = {
actions = {
sidekick_send = function(...)
- return require("sidekick.cli.snacks").send(...)
+ return require("sidekick.cli.picker.snacks").send(...)
end,
},
win = {
diff --git a/lua/lazyvim/plugins/extras/coding/blink.lua b/lua/lazyvim/plugins/extras/coding/blink.lua
index d5b9a57b..8d838237 100644
--- a/lua/lazyvim/plugins/extras/coding/blink.lua
+++ b/lua/lazyvim/plugins/extras/coding/blink.lua
@@ -37,9 +37,7 @@ return {
---@type blink.cmp.Config
opts = {
snippets = {
- expand = function(snippet, _)
- return LazyVim.cmp.expand(snippet)
- end,
+ preset = "default",
},
appearance = {
@@ -108,6 +106,9 @@ return {
},
---@param opts blink.cmp.Config | { sources: { compat: string[] } }
config = function(_, opts)
+ if opts.snippets and opts.snippets.preset == "default" then
+ opts.snippets.expand = LazyVim.cmp.expand
+ end
-- setup compat sources
local enabled = opts.sources.default
for _, source in ipairs(opts.sources.compat or {}) do
diff --git a/lua/lazyvim/plugins/extras/coding/mini-snippets.lua b/lua/lazyvim/plugins/extras/coding/mini-snippets.lua
index 714d867d..0262c388 100644
--- a/lua/lazyvim/plugins/extras/coding/mini-snippets.lua
+++ b/lua/lazyvim/plugins/extras/coding/mini-snippets.lua
@@ -1,6 +1,6 @@
if lazyvim_docs then
-- Set to `false` to prevent "non-lsp snippets"" from appearing inside completion windows
- -- Motivation: Less clutter in completion windows and a more direct usage of snippits
+ -- Motivation: Less clutter in completion windows and a more direct usage of snippets
vim.g.lazyvim_mini_snippets_in_completion = true
-- NOTE: Please also read:
diff --git a/lua/lazyvim/plugins/extras/coding/mini-surround.lua b/lua/lazyvim/plugins/extras/coding/mini-surround.lua
index 19c5de8f..bea4ece7 100644
--- a/lua/lazyvim/plugins/extras/coding/mini-surround.lua
+++ b/lua/lazyvim/plugins/extras/coding/mini-surround.lua
@@ -8,7 +8,7 @@ return {
-- Populate the keys based on the user's options
local opts = LazyVim.opts("mini.surround")
local mappings = {
- { opts.mappings.add, desc = "Add Surrounding", mode = { "n", "v" } },
+ { opts.mappings.add, desc = "Add Surrounding", mode = { "n", "x" } },
{ opts.mappings.delete, desc = "Delete Surrounding" },
{ opts.mappings.find, desc = "Find Right Surrounding" },
{ opts.mappings.find_left, desc = "Find Left Surrounding" },
diff --git a/lua/lazyvim/plugins/extras/dap/core.lua b/lua/lazyvim/plugins/extras/dap/core.lua
index d84b71bf..aaabce8d 100644
--- a/lua/lazyvim/plugins/extras/dap/core.lua
+++ b/lua/lazyvim/plugins/extras/dap/core.lua
@@ -84,7 +84,7 @@ return {
-- stylua: ignore
keys = {
{ "du", function() require("dapui").toggle({ }) end, desc = "Dap UI" },
- { "de", function() require("dapui").eval() end, desc = "Eval", mode = {"n", "v"} },
+ { "de", function() require("dapui").eval() end, desc = "Eval", mode = {"n", "x"} },
},
opts = {},
config = function(_, opts)
diff --git a/lua/lazyvim/plugins/extras/editor/dial.lua b/lua/lazyvim/plugins/extras/editor/dial.lua
index 602b747c..7a9a76ae 100644
--- a/lua/lazyvim/plugins/extras/editor/dial.lua
+++ b/lua/lazyvim/plugins/extras/editor/dial.lua
@@ -19,8 +19,8 @@ return {
keys = {
{ "", function() return M.dial(true) end, expr = true, desc = "Increment", mode = {"n", "v"} },
{ "", function() return M.dial(false) end, expr = true, desc = "Decrement", mode = {"n", "v"} },
- { "g", function() return M.dial(true, true) end, expr = true, desc = "Increment", mode = {"n", "v"} },
- { "g", function() return M.dial(false, true) end, expr = true, desc = "Decrement", mode = {"n", "v"} },
+ { "g", function() return M.dial(true, true) end, expr = true, desc = "Increment", mode = {"n", "x"} },
+ { "g", function() return M.dial(false, true) end, expr = true, desc = "Decrement", mode = {"n", "x"} },
},
opts = function()
local augend = require("dial.augend")
diff --git a/lua/lazyvim/plugins/extras/editor/fzf.lua b/lua/lazyvim/plugins/extras/editor/fzf.lua
index 9e7ef671..46e99ace 100644
--- a/lua/lazyvim/plugins/extras/editor/fzf.lua
+++ b/lua/lazyvim/plugins/extras/editor/fzf.lua
@@ -218,6 +218,7 @@ return {
{ "", LazyVim.pick("files"), desc = "Find Files (Root Dir)" },
-- find
{ "fb", "FzfLua buffers sort_mru=true sort_lastused=true", desc = "Buffers" },
+ { "fB", "FzfLua buffers", desc = "Buffers (all)" },
{ "fc", LazyVim.pick.config_files(), desc = "Find Config File" },
{ "ff", LazyVim.pick("files"), desc = "Find Files (Root Dir)" },
{ "fF", LazyVim.pick("files", { root = false }), desc = "Find Files (cwd)" },
@@ -226,15 +227,19 @@ return {
{ "fR", LazyVim.pick("oldfiles", { cwd = vim.uv.cwd() }), desc = "Recent (cwd)" },
-- git
{ "gc", "FzfLua git_commits", desc = "Commits" },
+ { "gd", "FzfLua git_diff", desc = "Git Diff (hunks)" },
+ { "gl", "FzfLua git_commits", desc = "Commits" },
{ "gs", "FzfLua git_status", desc = "Status" },
+ { "gS", "FzfLua git_stash", desc = "Git Stash" },
-- search
{ 's"', "FzfLua registers", desc = "Registers" },
+ { "s/", "FzfLua search_history", desc = "Search History" },
{ "sa", "FzfLua autocmds", desc = "Auto Commands" },
- { "sb", "FzfLua grep_curbuf", desc = "Buffer" },
+ { "sb", "FzfLua lines", desc = "Buffer Lines" },
{ "sc", "FzfLua command_history", desc = "Command History" },
{ "sC", "FzfLua commands", desc = "Commands" },
- { "sd", "FzfLua diagnostics_document", desc = "Document Diagnostics" },
- { "sD", "FzfLua diagnostics_workspace", desc = "Workspace Diagnostics" },
+ { "sd", "FzfLua diagnostics_workspace", desc = "Diagnostics" },
+ { "sD", "FzfLua diagnostics_document", desc = "Buffer Diagnostics" },
{ "sg", LazyVim.pick("live_grep"), desc = "Grep (Root Dir)" },
{ "sG", LazyVim.pick("live_grep", { root = false }), desc = "Grep (cwd)" },
{ "sh", "FzfLua help_tags", desc = "Help Pages" },
@@ -248,8 +253,8 @@ return {
{ "sq", "FzfLua quickfix", desc = "Quickfix List" },
{ "sw", LazyVim.pick("grep_cword"), desc = "Word (Root Dir)" },
{ "sW", LazyVim.pick("grep_cword", { root = false }), desc = "Word (cwd)" },
- { "sw", LazyVim.pick("grep_visual"), mode = "v", desc = "Selection (Root Dir)" },
- { "sW", LazyVim.pick("grep_visual", { root = false }), mode = "v", desc = "Selection (cwd)" },
+ { "sw", LazyVim.pick("grep_visual"), mode = "x", desc = "Selection (Root Dir)" },
+ { "sW", LazyVim.pick("grep_visual", { root = false }), mode = "x", desc = "Selection (cwd)" },
{ "uC", LazyVim.pick("colorschemes"), desc = "Colorscheme with Preview" },
{
"ss",
diff --git a/lua/lazyvim/plugins/extras/editor/telescope.lua b/lua/lazyvim/plugins/extras/editor/telescope.lua
index 9fdf7e13..0f5ee474 100644
--- a/lua/lazyvim/plugins/extras/editor/telescope.lua
+++ b/lua/lazyvim/plugins/extras/editor/telescope.lua
@@ -101,6 +101,7 @@ return {
"Telescope buffers sort_mru=true sort_lastused=true ignore_current_buffer=true",
desc = "Buffers",
},
+ { "fB", "Telescope buffers", desc = "Buffers (all)" },
{ "fc", LazyVim.pick.config_files(), desc = "Find Config File" },
{ "ff", LazyVim.pick("files"), desc = "Find Files (Root Dir)" },
{ "fF", LazyVim.pick("files", { root = false }), desc = "Find Files (cwd)" },
@@ -109,15 +110,18 @@ return {
{ "fR", LazyVim.pick("oldfiles", { cwd = vim.uv.cwd() }), desc = "Recent (cwd)" },
-- git
{ "gc", "Telescope git_commits", desc = "Commits" },
+ { "gl", "Telescope git_commits", desc = "Commits" },
{ "gs", "Telescope git_status", desc = "Status" },
+ { "gS", "Telescope git_stash", desc = "Git Stash" },
-- search
{ 's"', "Telescope registers", desc = "Registers" },
+ { "s/", "Telescope search_history", desc = "Search History" },
{ "sa", "Telescope autocommands", desc = "Auto Commands" },
- { "sb", "Telescope current_buffer_fuzzy_find", desc = "Buffer" },
+ { "sb", "Telescope current_buffer_fuzzy_find", desc = "Buffer Lines" },
{ "sc", "Telescope command_history", desc = "Command History" },
{ "sC", "Telescope commands", desc = "Commands" },
- { "sd", "Telescope diagnostics bufnr=0", desc = "Document Diagnostics" },
- { "sD", "Telescope diagnostics", desc = "Workspace Diagnostics" },
+ { "sd", "Telescope diagnostics", desc = "Diagnostics" },
+ { "sD", "Telescope diagnostics bufnr=0", desc = "Buffer Diagnostics" },
{ "sg", LazyVim.pick("live_grep"), desc = "Grep (Root Dir)" },
{ "sG", LazyVim.pick("live_grep", { root = false }), desc = "Grep (cwd)" },
{ "sh", "Telescope help_tags", desc = "Help Pages" },
@@ -132,8 +136,8 @@ return {
{ "sq", "Telescope quickfix", desc = "Quickfix List" },
{ "sw", LazyVim.pick("grep_string", { word_match = "-w" }), desc = "Word (Root Dir)" },
{ "sW", LazyVim.pick("grep_string", { root = false, word_match = "-w" }), desc = "Word (cwd)" },
- { "sw", LazyVim.pick("grep_string"), mode = "v", desc = "Selection (Root Dir)" },
- { "sW", LazyVim.pick("grep_string", { root = false }), mode = "v", desc = "Selection (cwd)" },
+ { "sw", LazyVim.pick("grep_string"), mode = "x", desc = "Selection (Root Dir)" },
+ { "sW", LazyVim.pick("grep_string", { root = false }), mode = "x", desc = "Selection (cwd)" },
{ "uC", LazyVim.pick("colorscheme", { enable_preview = true }), desc = "Colorscheme with Preview" },
{
"ss",
diff --git a/lua/lazyvim/plugins/extras/lang/clangd.lua b/lua/lazyvim/plugins/extras/lang/clangd.lua
index 0ba58aca..cac83194 100644
--- a/lua/lazyvim/plugins/extras/lang/clangd.lua
+++ b/lua/lazyvim/plugins/extras/lang/clangd.lua
@@ -60,7 +60,7 @@ return {
-- Ensure mason installs the server
clangd = {
keys = {
- { "ch", "ClangdSwitchSourceHeader", desc = "Switch Source/Header (C/C++)" },
+ { "ch", "LspClangdSwitchSourceHeader", desc = "Switch Source/Header (C/C++)" },
},
root_markers = {
"compile_commands.json",
diff --git a/lua/lazyvim/plugins/extras/lang/clojure.lua b/lua/lazyvim/plugins/extras/lang/clojure.lua
index c7af0b55..4c47c623 100644
--- a/lua/lazyvim/plugins/extras/lang/clojure.lua
+++ b/lua/lazyvim/plugins/extras/lang/clojure.lua
@@ -76,13 +76,13 @@ return {
end
vim.keymap.set(
- { "n", "v" },
+ { "n", "x" },
"[c",
"call search('^; -\\+$', 'bw')",
{ silent = true, buffer = true, desc = "Jumps to the begining of previous evaluation output." }
)
vim.keymap.set(
- { "n", "v" },
+ { "n", "x" },
"]c",
"call search('^; -\\+$', 'w')",
{ silent = true, buffer = true, desc = "Jumps to the begining of next evaluation output." }
diff --git a/lua/lazyvim/plugins/extras/lang/dart.lua b/lua/lazyvim/plugins/extras/lang/dart.lua
new file mode 100644
index 00000000..c912b5bf
--- /dev/null
+++ b/lua/lazyvim/plugins/extras/lang/dart.lua
@@ -0,0 +1,40 @@
+return {
+ recommended = function()
+ return LazyVim.extras.wants({
+ ft = "dart",
+ root = { "pubspec.yaml" },
+ })
+ end,
+ {
+ "neovim/nvim-lspconfig",
+ opts = {
+ servers = {
+ dartls = {},
+ },
+ },
+ },
+ {
+ "nvim-treesitter/nvim-treesitter",
+ opts = { ensure_installed = { "dart" } },
+ },
+ {
+ "stevearc/conform.nvim",
+ opts = {
+ formatters_by_ft = {
+ dart = { "dart_format" },
+ },
+ },
+ },
+ {
+ "nvim-neotest/neotest",
+ optional = true,
+ dependencies = {
+ "sidlatau/neotest-dart",
+ },
+ opts = {
+ adapters = {
+ ["neotest-dart"] = {},
+ },
+ },
+ },
+}
diff --git a/lua/lazyvim/plugins/extras/lang/docker.lua b/lua/lazyvim/plugins/extras/lang/docker.lua
index ea26b013..a3c48c10 100644
--- a/lua/lazyvim/plugins/extras/lang/docker.lua
+++ b/lua/lazyvim/plugins/extras/lang/docker.lua
@@ -2,7 +2,14 @@ return {
recommended = function()
return LazyVim.extras.wants({
ft = "dockerfile",
- root = { "Dockerfile", "docker-compose.yml", "compose.yml", "docker-compose.yaml", "compose.yaml" },
+ root = {
+ "Dockerfile",
+ "Containerfile",
+ "docker-compose.yml",
+ "compose.yml",
+ "docker-compose.yaml",
+ "compose.yaml",
+ },
})
end,
{
diff --git a/lua/lazyvim/plugins/extras/lang/ember.lua b/lua/lazyvim/plugins/extras/lang/ember.lua
new file mode 100644
index 00000000..d16ea82d
--- /dev/null
+++ b/lua/lazyvim/plugins/extras/lang/ember.lua
@@ -0,0 +1,29 @@
+return {
+ recommended = function()
+ return LazyVim.extras.wants({
+ ft = { "handlebars", "typescript", "javascript", "typescript.glimmer", "javascript.glimmer" },
+ root = { "ember-cli-build.js", ".git" },
+ })
+ end,
+ {
+ "nvim-treesitter/nvim-treesitter",
+ opts = { ensure_installed = { "css", "glimmer", "glimmer_javascript", "glimmer_typescript" } },
+ },
+ {
+ "neovim/nvim-lspconfig",
+ opts = {
+ servers = {
+ ember = {},
+ },
+ },
+ },
+ {
+ "conform.nvim",
+ opts = function(_, opts)
+ if LazyVim.has_extra("formatting.prettier") then
+ opts.formatters_by_ft = opts.formatters_by_ft or {}
+ opts.formatters_by_ft.glimmer = { "prettier" }
+ end
+ end,
+ },
+}
diff --git a/lua/lazyvim/plugins/extras/lang/go.lua b/lua/lazyvim/plugins/extras/lang/go.lua
index 77536fea..86f984f5 100644
--- a/lua/lazyvim/plugins/extras/lang/go.lua
+++ b/lua/lazyvim/plugins/extras/lang/go.lua
@@ -97,6 +97,22 @@ return {
})
end,
},
+ -- Add linting
+ {
+ "mfussenegger/nvim-lint",
+ optional = true,
+ dependencies = {
+ {
+ "mason-org/mason.nvim",
+ opts = { ensure_installed = { "golangci-lint" } },
+ },
+ },
+ opts = {
+ linters_by_ft = {
+ go = { "golangcilint" },
+ },
+ },
+ },
{
"stevearc/conform.nvim",
optional = true,
diff --git a/lua/lazyvim/plugins/extras/lang/haskell.lua b/lua/lazyvim/plugins/extras/lang/haskell.lua
index 48634f2d..cf4f3db6 100644
--- a/lua/lazyvim/plugins/extras/lang/haskell.lua
+++ b/lua/lazyvim/plugins/extras/lang/haskell.lua
@@ -14,17 +14,40 @@ return {
{
"mrcjkb/haskell-tools.nvim",
- version = "^3",
+ version = false,
ft = { "haskell", "lhaskell", "cabal", "cabalproject" },
- dependencies = {
- { "nvim-telescope/telescope.nvim", optional = true },
+ keys = {
+ {
+ "e",
+ "HlsEvalAll",
+ ft = "haskell",
+ desc = "Evaluate All",
+ },
+ {
+ "h",
+ function()
+ require("haskell-tools").hoogle.hoogle_signature()
+ end,
+ ft = "haskell",
+ desc = "Hoogle Signature",
+ },
+ {
+ "r",
+ function()
+ require("haskell-tools").repl.toggle()
+ end,
+ ft = "haskell",
+ desc = "REPL (Package)",
+ },
+ {
+ "R",
+ function()
+ require("haskell-tools").repl.toggle(vim.api.nvim_buf_get_name(0))
+ end,
+ ft = "haskell",
+ desc = "REPL (Buffer)",
+ },
},
- config = function()
- local ok, telescope = pcall(require, "telescope")
- if ok then
- telescope.load_extension("ht")
- end
- end,
},
{
@@ -67,17 +90,48 @@ return {
},
{
- "luc-tielen/telescope_hoogle",
- ft = { "haskell", "lhaskell", "cabal", "cabalproject" },
- dependencies = {
- { "nvim-telescope/telescope.nvim", optional = true },
+ "nvim-telescope/telescope.nvim",
+ optional = true,
+ specs = {
+ {
+ "luc-tielen/telescope_hoogle",
+ ft = { "haskell", "lhaskell", "cabal", "cabalproject" },
+ opts = function()
+ LazyVim.on_load("telescope.nvim", function()
+ require("telescope").load_extension("ht")
+ end)
+ end,
+ keys = {
+ {
+ "H",
+ "Telescope hoogle",
+ ft = "haskell",
+ desc = "Hoogle",
+ },
+ },
+ },
+ },
+ },
+
+ {
+ "stevearc/conform.nvim",
+ optional = true,
+ opts = {
+ formatters_by_ft = {
+ haskell = { "fourmolu" },
+ cabal = { "cabal_fmt" },
+ },
+ },
+ },
+
+ {
+ "mfussenegger/nvim-lint",
+ optional = true,
+ opts = {
+ linters_by_ft = {
+ haskell = { "hlint" },
+ },
},
- config = function()
- local ok, telescope = pcall(require, "telescope")
- if ok then
- telescope.load_extension("hoogle")
- end
- end,
},
-- Make sure lspconfig doesn't start hls,
diff --git a/lua/lazyvim/plugins/extras/lang/helm.lua b/lua/lazyvim/plugins/extras/lang/helm.lua
index 58d8bdc8..5c85d191 100644
--- a/lua/lazyvim/plugins/extras/lang/helm.lua
+++ b/lua/lazyvim/plugins/extras/lang/helm.lua
@@ -6,7 +6,8 @@ return {
})
end,
- { "towolf/vim-helm", ft = "helm" },
+ { "qvalentin/helm-ls.nvim", ft = "helm" },
+
{
"nvim-treesitter/nvim-treesitter",
opts = { ensure_installed = { "helm" } },
@@ -18,17 +19,6 @@ return {
servers = {
helm_ls = {},
},
- setup = {
- yamlls = function()
- LazyVim.lsp.on_attach(function(client, buffer)
- if vim.bo[buffer].filetype == "helm" then
- vim.schedule(function()
- vim.cmd("LspStop ++force yamlls")
- end)
- end
- end, "yamlls")
- end,
- },
},
},
}
diff --git a/lua/lazyvim/plugins/extras/lang/java.lua b/lua/lazyvim/plugins/extras/lang/java.lua
index 4dd1d77f..b86688b1 100644
--- a/lua/lazyvim/plugins/extras/lang/java.lua
+++ b/lua/lazyvim/plugins/extras/lang/java.lua
@@ -169,7 +169,9 @@ return {
},
settings = opts.settings,
-- enable CMP capabilities
- capabilities = LazyVim.has("cmp-nvim-lsp") and require("cmp_nvim_lsp").default_capabilities() or nil,
+ capabilities = LazyVim.has("blink.cmp") and require("blink.cmp").get_lsp_capabilities() or LazyVim.has(
+ "cmp-nvim-lsp"
+ ) and require("cmp_nvim_lsp").default_capabilities() or nil,
}, opts.jdtls)
-- Existing server will be reused if the root_dir matches.
@@ -207,7 +209,7 @@ return {
})
wk.add({
{
- mode = "v",
+ mode = "x",
buffer = args.buf,
{ "cx", group = "extract" },
{
diff --git a/lua/lazyvim/plugins/extras/lang/julia.lua b/lua/lazyvim/plugins/extras/lang/julia.lua
new file mode 100644
index 00000000..067be457
--- /dev/null
+++ b/lua/lazyvim/plugins/extras/lang/julia.lua
@@ -0,0 +1,66 @@
+return {
+ recommended = function()
+ return LazyVim.extras.wants({
+ ft = { "julia" },
+ root = { "Project.toml" },
+ })
+ end,
+
+ {
+ "nvim-treesitter/nvim-treesitter",
+ opts = { ensure_installed = { "julia" } },
+ },
+
+ {
+ "neovim/nvim-lspconfig",
+ opts = {
+ servers = {
+ julials = {
+ settings = {
+ -- use the same default settings as the Julia VS Code extension
+ julia = {
+ completionmode = "qualify",
+ lint = { missingrefs = "none" },
+ },
+ },
+ },
+ },
+ },
+ },
+
+ -- cmp integration
+ {
+ "hrsh7th/nvim-cmp",
+ optional = true,
+ dependencies = { "kdheepak/cmp-latex-symbols" },
+ opts = function(_, opts)
+ table.insert(opts.sources, {
+ name = "latex_symbols",
+ option = {
+ strategy = 0, -- mixed
+ },
+ })
+ end,
+ },
+
+ -- blink.cmp integration
+ {
+ "saghen/blink.cmp",
+ optional = true,
+ dependencies = { "kdheepak/cmp-latex-symbols", "saghen/blink.compat" },
+ opts = {
+ sources = {
+ compat = { "latex_symbols" },
+ providers = {
+ latex_symbols = {
+ kind = "LatexSymbols",
+ async = true,
+ opts = {
+ strategy = 0, -- mixed
+ },
+ },
+ },
+ },
+ },
+ },
+}
diff --git a/lua/lazyvim/plugins/extras/lang/lean.lua b/lua/lazyvim/plugins/extras/lang/lean.lua
index 58488372..76db7ecb 100644
--- a/lua/lazyvim/plugins/extras/lang/lean.lua
+++ b/lua/lazyvim/plugins/extras/lang/lean.lua
@@ -108,7 +108,7 @@ return {
priority = 10,
},
- -- Redirect Lean's stderr messages somehwere (to a buffer by default)
+ -- Redirect Lean's stderr messages somewhere (to a buffer by default)
stderr = {
enable = true,
-- height of the window
diff --git a/lua/lazyvim/plugins/extras/lang/nix.lua b/lua/lazyvim/plugins/extras/lang/nix.lua
index 76a42ebe..79a2b71f 100644
--- a/lua/lazyvim/plugins/extras/lang/nix.lua
+++ b/lua/lazyvim/plugins/extras/lang/nix.lua
@@ -24,4 +24,13 @@ return {
},
},
},
+ {
+ "mfussenegger/nvim-lint",
+ optional = true,
+ opts = {
+ linters_by_ft = {
+ nix = { "statix" },
+ },
+ },
+ },
}
diff --git a/lua/lazyvim/plugins/extras/lang/php.lua b/lua/lazyvim/plugins/extras/lang/php.lua
index 04469223..98fffdb0 100644
--- a/lua/lazyvim/plugins/extras/lang/php.lua
+++ b/lua/lazyvim/plugins/extras/lang/php.lua
@@ -83,4 +83,21 @@ return {
},
},
},
+
+ {
+ "nvim-neotest/neotest",
+ optional = true,
+ dependencies = {
+ "V13Axel/neotest-pest",
+ "olimorris/neotest-phpunit",
+ },
+ opts = {
+ adapters = {
+ "neotest-pest",
+ ["neotest-phpunit"] = {
+ root_ignore_files = { "tests/Pest.php" },
+ },
+ },
+ },
+ },
}
diff --git a/lua/lazyvim/plugins/extras/lang/python.lua b/lua/lazyvim/plugins/extras/lang/python.lua
index a02ded1f..7a77cbc6 100644
--- a/lua/lazyvim/plugins/extras/lang/python.lua
+++ b/lua/lazyvim/plugins/extras/lang/python.lua
@@ -103,11 +103,7 @@ return {
{ "dPc", function() require('dap-python').test_class() end, desc = "Debug Class", ft = "python" },
},
config = function()
- if vim.fn.has("win32") == 1 then
- require("dap-python").setup(LazyVim.get_pkg_path("debugpy", "/venv/Scripts/pythonw.exe"))
- else
- require("dap-python").setup(LazyVim.get_pkg_path("debugpy", "/venv/bin/python"))
- end
+ require("dap-python").setup("debugpy-adapter")
end,
},
},
diff --git a/lua/lazyvim/plugins/extras/lang/r.lua b/lua/lazyvim/plugins/extras/lang/r.lua
index f8feb0ea..5890b415 100644
--- a/lua/lazyvim/plugins/extras/lang/r.lua
+++ b/lua/lazyvim/plugins/extras/lang/r.lua
@@ -17,12 +17,12 @@ return {
-- of files supported by R.nvim. This is an
-- opportunity to create mappings local to buffers.
vim.keymap.set("n", "", "RDSendLine", { buffer = true })
- vim.keymap.set("v", "", "RSendSelection", { buffer = true })
+ vim.keymap.set("x", "
diff --git a/lua/lazyvim/plugins/extras/lang/omnisharp.lua b/lua/lazyvim/plugins/extras/lang/dotnet.lua
similarity index 82%
rename from lua/lazyvim/plugins/extras/lang/omnisharp.lua
rename to lua/lazyvim/plugins/extras/lang/dotnet.lua
index 07ba0490..433ab154 100644
--- a/lua/lazyvim/plugins/extras/lang/omnisharp.lua
+++ b/lua/lazyvim/plugins/extras/lang/dotnet.lua
@@ -1,15 +1,15 @@
return {
recommended = function()
return LazyVim.extras.wants({
- ft = { "cs", "vb" },
- root = { "*.sln", "*.csproj", "omnisharp.json", "function.json" },
+ ft = { "cs", "vb", "fsharp" },
+ root = { "*.sln", "*.csproj", "*.fsproj", "omnisharp.json", "function.json", "paket.dependencies", "paket.lock" },
})
end,
{ "Hoffs/omnisharp-extended-lsp.nvim", lazy = true },
{
"nvim-treesitter/nvim-treesitter",
- opts = { ensure_installed = { "c_sharp" } },
+ opts = { ensure_installed = { "c_sharp", "fsharp" } },
},
{
"nvimtools/none-ls.nvim",
@@ -18,6 +18,7 @@ return {
local nls = require("null-ls")
opts.sources = opts.sources or {}
table.insert(opts.sources, nls.builtins.formatting.csharpier)
+ table.insert(opts.sources, nls.builtins.formatting.fantomas)
end,
},
{
@@ -26,23 +27,19 @@ return {
opts = {
formatters_by_ft = {
cs = { "csharpier" },
- },
- formatters = {
- csharpier = {
- command = "dotnet-csharpier",
- args = { "--write-stdout" },
- },
+ fsharp = { "fantomas" },
},
},
},
{
"mason-org/mason.nvim",
- opts = { ensure_installed = { "csharpier", "netcoredbg" } },
+ opts = { ensure_installed = { "csharpier", "netcoredbg", "fantomas" } },
},
{
"neovim/nvim-lspconfig",
opts = {
servers = {
+ fsautocomplete = {},
omnisharp = {
handlers = {
["textDocument/definition"] = function(...)
@@ -104,12 +101,12 @@ return {
"nvim-neotest/neotest",
optional = true,
dependencies = {
- "Issafalcon/neotest-dotnet",
+ "Nsidorenco/neotest-vstest",
},
opts = {
adapters = {
- ["neotest-dotnet"] = {
- -- Here we can set options for neotest-dotnet
+ ["neotest-vstest"] = {
+ -- Here we can set options for neotest-vstest
},
},
},